@@ -3,6 +3,7 @@
 #' @param Longitudinal A list of longitudinal predictors which should contain: \code{X} a dataframe with one row for repeated measurement and as many columns as markers; \code{id} is the vector of the identifiers for the repeated measurements contained in \code{X}; \code{time} is the vector of the measurement times contained in \code{X}.
 #' @param Numeric A list of numeric predictors which should contain: \code{X} a dataframe with as many columns as numeric predictors; \code{id} is the vector of the identifiers for each individual.
 #' @param Factor A list of categorical predictors which should contain: \code{X} a dataframe with as many columns as categorical predictors; \code{id} is the vector of the identifiers for each individual.
+#' @param timeVar A character indicating the name of time variable
 #' @param Y A list of output which should contain: \code{type} defines the nature of the output, can be "\code{surv}", "\code{numeric}" or "\code{factor}"; \code{Y} is the outcome variable; \code{id} is the vector of the identifiers for each individuals, they should be the same as the identifiers of the inputs.
 #' @param mtry Number of candidate variables randomly drawn at each node of the trees. This parameter should be tuned by minimizing the OOB error. Default is `NULL`.
 #' @param ntree Number of trees to grow. Default value set to 200.
@@ -20,7 +21,8 @@
 #' @importFrom splines ns
 #'
 #' @keywords internal
-rf_shape_para <- function(Longitudinal = NULL, Numeric = NULL, Factor = NULL, Y, mtry, ntree, ncores,
+rf_shape_para <- function(Longitudinal = NULL, Numeric = NULL, Factor = NULL,
+                          timeVar = NULL, Y, mtry, ntree, ncores,
                           nsplit_option = "quantile", nodesize = 1, minsplit = 2, cause = 1,
                           seed = 1234, verbose = TRUE){
 
@@ -43,16 +45,17 @@ rf_shape_para <- function(Longitudinal = NULL, Numeric = NULL, Factor = NULL, Y,
 
     if (Y$type=="surv"){
       trees <- pbsapply(1:ntree, FUN=function(i){
-        DynTree_surv(Y = Y, Longitudinal = Longitudinal, Numeric = Numeric, Factor = Factor, mtry = mtry,
-                     nsplit_option = nsplit_option, nodesize = nodesize, minsplit = minsplit, cause = cause,
+        DynTree_surv(Y = Y, Longitudinal = Longitudinal, Numeric = Numeric, Factor = Factor,
+                     timeVar = timeVar, mtry = mtry, nsplit_option = nsplit_option,
+                     nodesize = nodesize, minsplit = minsplit, cause = cause,
                      seed = seed*i)
       },cl=cl)
     }
     if (Y$type%in%c("factor","numeric")){
       trees <- pbsapply(1:ntree, FUN=function(i){
-        DynTree(Y = Y, Longitudinal = Longitudinal, Numeric = Numeric, Factor = Factor, mtry = mtry,
-                nsplit_option = nsplit_option, nodesize = nodesize,
-                seed = seed*i)
+        DynTree(Y = Y, Longitudinal = Longitudinal, Numeric = Numeric, Factor = Factor,
+                timeVar = timeVar, mtry = mtry, nsplit_option = nsplit_option,
+                nodesize = nodesize, seed = seed*i)
       },cl=cl)
     }
 
@@ -62,16 +65,17 @@ rf_shape_para <- function(Longitudinal = NULL, Numeric = NULL, Factor = NULL, Y,
 
     if (Y$type=="surv"){
       trees <- pbsapply(1:ntree, FUN=function(i){
-        DynTree_surv(Y = Y, Longitudinal = Longitudinal, Numeric = Numeric, Factor = Factor, mtry = mtry,
-                     nsplit_option = nsplit_option, nodesize = nodesize, minsplit = minsplit, cause = cause,
+        DynTree_surv(Y = Y, Longitudinal = Longitudinal, Numeric = Numeric, Factor = Factor,
+                     timeVar = timeVar, mtry = mtry, nsplit_option = nsplit_option,
+                     nodesize = nodesize, minsplit = minsplit, cause = cause,
                      seed = seed*i)
       },cl=NULL)
     }
     if (Y$type%in%c("factor","numeric")){
       trees <- pbsapply(1:ntree, FUN=function(i){
-        DynTree(Y = Y, Longitudinal = Longitudinal, Numeric = Numeric, Factor = Factor, mtry = mtry,
-                nsplit_option = nsplit_option, nodesize = nodesize,
-                seed = seed*i)
+        DynTree(Y = Y, Longitudinal = Longitudinal, Numeric = Numeric, Factor = Factor,
+                timeVar = timeVar, mtry = mtry, nsplit_option = nsplit_option,
+                nodesize = nodesize, seed = seed*i)
       },cl=NULL)
     }
 
