@@ -93,25 +93,27 @@ var_split <- function(X, Y, timeVar = NULL, nsplit_option = "quantile",
 
         if (is.null(model_output)){ # can occurred with Cholesky matrix inversion
 
-          model_output <- hlme(fixed = X$model[[i]]$fixed,
-                               random = X$model[[i]]$random,
-                               subject = "id", data = data_model,
-                               maxiter = 100,
-                               verbose = FALSE)
+          model_output <- tryCatch(hlme(fixed = X$model[[i]]$fixed,
+                                        random = X$model[[i]]$random,
+                                        subject = "id", data = data_model,
+                                        maxiter = 100,
+                                        verbose = FALSE),
+                                   error = function(e){ return(NULL) })
 
         }
 
       }else{
 
-        model_output <- hlme(fixed = X$model[[i]]$fixed,
-                             random = X$model[[i]]$random,
-                             subject = "id", data = data_model,
-                             maxiter = 100,
-                             verbose = FALSE)
+        model_output <- tryCatch(hlme(fixed = X$model[[i]]$fixed,
+                                      random = X$model[[i]]$random,
+                                      subject = "id", data = data_model,
+                                      maxiter = 100,
+                                      verbose = FALSE),
+                                 error = function(e){ return(NULL) })
 
       }
 
-      if (model_output$gconv[1]>1e-04 | model_output$gconv[2]>1e-04){ # convergence issue
+      if (model_output$gconv[1]>1e-04 | model_output$gconv[2]>1e-04 | is.null(model_output)){ # convergence issue
 
         impur[i] <- Inf
         split[[i]] <- Inf
@@ -127,9 +129,8 @@ var_split <- function(X, Y, timeVar = NULL, nsplit_option = "quantile",
                                stderr = tail(model_output$best, n = 1),
                                idea0 = model_output$idea0)
 
-      #RE <- predRE(model_param[[i]], X$model[[i]], data_model)$bi
-      RE <- model_output$predRE[order(match(model_output$predRE$id, Y$id)), -1]
-      rownames(RE) <- unique(Y$id)
+      # Random-effect dataframe with NA for subjects where RE cannot be computed
+      RE <- merge(unique(Y$id), model_output$predRE, all.x = T, by.x = "x", by.y = "id")[,-1]
 
       ###########################
 
@@ -151,7 +152,8 @@ var_split <- function(X, Y, timeVar = NULL, nsplit_option = "quantile",
 
         if (!all(is.na(data_summaries[,i_sum]))){
 
-          nsplit <- ifelse(length(unique(data_summaries[,i_sum]))>10, 10, length(unique(data_summaries[,i_sum])))
+          nsplit <- ifelse(length(unique(na.omit(data_summaries[,i_sum])))>10,
+                           10, length(unique(na.omit(data_summaries[,i_sum]))))
 
           if (nsplit==1) {
             impurete_sum[i_sum] <- NA
